@@ -4,8 +4,8 @@ import { changeDirection } from '../../redux/actions';
 import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
 
 const JourneyTypeSelect = ({ depart, changeDirection }) => {
-    const leave = depart === 'DUNDEE' ? 'Dundee' : 'Edinburgh Airport';
-    const arrive = depart === 'DUNDEE' ? 'Edinburgh Airport' : 'Dundee';
+    const leave = depart === 'DUNDEE' ? 'Dundee, Union Street ' : 'Edinburgh Airport';
+    const arrive = depart === 'DUNDEE' ? 'Edinburgh Airport' : 'Dundee, Union Street ';
     return (
         <div className="direction-select">
             <div>{leave}</div>
