@@ -50,7 +50,7 @@ class BookingController
             <head>
                 <meta name="viewport" content="width=device-width, initial-scale=1">
                 <link rel="profile" href="http://gmpg.org/xfn/11">
-                <META HTTP-EQUIV="Refresh" CONTENT="3; URL=http://booking.nxdiscovrit.co.uk/booking/?complete=' . $bookingId . '">
+                <META HTTP-EQUIV="Refresh" CONTENT="3; URL=http://booking.xploremore.co.uk/booking/?complete=' . $bookingId . '">
             </head>
             <WPDISPLAY FILE="header.html">
             <body>
@@ -92,15 +92,17 @@ class BookingController
             return new \WP_REST_Response('No id was sent', 400);
         }
 
-        $outboundJourney = get_field('outbound_journey', $bookingId);
+        $outboundJourneyId = get_field('outbound_journey', $bookingId)[0];
         $outboundRef = get_field('outbound_reference', $bookingId);
-        $response[] = self::getFormattedJourneyText($outboundJourney[0]->post_title, $outboundRef);
+        $response[] = self::getFormattedJourneyText(get_the_title($outboundJourneyId), $outboundRef);
 
-        $inboundJourney = get_field('inbound_journey', $bookingId);
-        if($inboundJourney) {
+        $inboundJourneyId = get_field('inbound_journey', $bookingId)[0];
+        if($inboundJourneyId) {
             $inboundRef = get_field('inbound_reference', $bookingId);
-            $response[] = self::getFormattedJourneyText($inboundJourney[0]->post_title, $inboundRef);
+            $response[] = self::getFormattedJourneyText(get_the_title($inboundJourneyId), $inboundRef);
         }
+        $email = get_field('email', $bookingId);
+        $response[] = "An email will be sent to $email";
 
         return $response;
     }
@@ -117,21 +119,21 @@ class BookingController
         $name = get_field('name', $bookingId);
         $surname = get_field('surname', $bookingId);
         $paymentReference = get_field('payment_reference', $bookingId);
-
         switch ($status) {
             case 'paid':
                 $subject = 'Edinburgh Airport Xpress - successful booking for ' . $paymentReference;
                 $tickets = get_field('tickets', $bookingId);
-                $outboundJourney = get_field('outbound_journey', $bookingId);
-                $outboundJourney = get_the_title($outboundJourney[0]);
+                $outboundJourneyId = get_field('outbound_journey', $bookingId)[0];
+                $outboundJourney = get_the_title($outboundJourneyId);
                 $outboundReference = get_field('outbound_reference', $bookingId);
 
-                $inboundJourney = get_field('inbound_journey', $bookingId);
-                $inboundJourney = get_the_title($inboundJourney[0]);
+                $inboundJourneyId = get_field('inbound_journey', $bookingId)[0];
+                $inboundJourney = get_the_title($inboundJourneyId);
                 $inboundReference = get_field('inbound_reference', $bookingId);
                 $addOns = get_field('add_ons', $paymentReference);
 
-                $body = '<p>Dear ' . $name . ' ' . $surname . '</p>';
+                $body = '<img src="' . get_field('logo', 'options') . '" style="max-width: 200px; height: auto; margin-bottom: 15px;"> <br>';
+                $body .= '<p>Dear ' . $name . ' ' . $surname . '</p>';
                 $body .= '<p>Thank you for booking the Xplore More Edinburgh Airport Xpress Service from/to Dundee.   Below you will find your booking and journey details for you/your party - please check these carefully.</p>';
                 $body .= '<p><strong>This confirmation is your coach ticket and must be shown to the driver when boarding the vehicle, and all members of your party must be present at the time of boarding.</strong></p><br>';
                 $body .= '<p><strong>Booking Name: </strong>' . $name . ' ' . $surname . '.</p>';
@@ -146,6 +148,19 @@ class BookingController
                 if ($inboundJourney) {
                     $body .= self::getFormattedJourneyText($inboundJourney, $inboundReference);
                 }
+                $body .= '<p>
+                            <strong>Scottish Concessionary Card Holders</strong> <br />
+                            All Scottish Concessionary Card Holders must ensure that they present their cards to
+                            the driver and scan them on the ticket machines to obtain their concessionary
+                            tickets. If you are unable to present your concessionary card you will be asked to
+                            pay the relevant standard fare for your journey.
+                        </p>';
+                $body .= '<p>
+                            <strong>Students</strong> <br />
+                            Students should ensure that they have a current and valid matriculation card or
+                            letter of acceptance at a college/university available to show to the driver prior
+                            to boarding the coach.
+                        </p>';
                 $body .= '<p><strong>Have an enjoyable trip.</strong></p>';
                 break;
             case 'failed':
@@ -163,7 +178,7 @@ class BookingController
     public function addNewBooking($request)
     {
         $requiredFields = [
-            'name',
+            'firstName',
             'surname',
             'email',
             'phoneNumber',
@@ -176,7 +191,7 @@ class BookingController
             }
         }
 
-        $name = $request['name'];
+        $name = $request['firstName'];
         $surname = $request['surname'];
         $email = $request['email'];
         $phone = $request['phoneNumber'];
@@ -185,12 +200,21 @@ class BookingController
 
         $outboundSlug = $request['outbound'];
         $outboundReference = explode('-', $outboundSlug);
+        $outboundDateString = $outboundReference[4].'/'.$outboundReference[5].'/'.$outboundReference[6];
+        $outboundDate = \DateTime::createFromFormat('d/m/Y', $outboundDateString);
+        $outboundDate = $outboundDate->format('Ymd');
+
         $outboundReference = strtoupper($outboundReference[0] . '-' . $outboundReference[2] . '-' . $outboundReference[3] . '-' . mt_rand(00000, 99999));
         $outboundJourney = self::updateOrInsertPostJourney($outboundSlug, $seats);
 
         if(isset($request['inbound']) && $request['inbound'] !== false) {
             $inboundSlug = $request['inbound'];
             $inboundReference = explode('-', $inboundSlug);
+            $inboundDateString = $inboundReference[4].'/'.$inboundReference[5].'/'.$inboundReference[6];
+            $inboundDate = \DateTime::createFromFormat('d/m/Y', $inboundDateString);
+            $inboundDate = $inboundDate->format('Ymd');
+
+
             $inboundReference = strtoupper($inboundReference[0].'-'.$inboundReference[2].'-'.$inboundReference[3].'-'.mt_rand(00000, 99999));
             $inboundJourney = self::updateOrInsertPostJourney($inboundSlug, $seats);
         }
@@ -218,9 +242,9 @@ class BookingController
 
             $newBooking = wp_insert_post($args);
             update_field('tickets', $tickets, $newBooking);
-            update_field('field_5cf5622486fd7', $outboundJourney, $newBooking);
+            update_field('outbound_journey', [$outboundJourney], $newBooking);
             update_field('outbound_reference', $outboundReference, $newBooking);
-            update_field('field_5cf7f1b976a3b', $inboundJourney, $newBooking);
+            update_field('inbound_journey', [$inboundJourney], $newBooking);
             update_field('inbound_reference', $inboundReference, $newBooking);
             update_field('add_ons', $addOns, $newBooking);
             update_field('name', $name, $newBooking);
@@ -228,7 +252,8 @@ class BookingController
             update_field('email', $email, $newBooking);
             update_field('phone_number', $phone, $newBooking);
             update_field('price', $price, $newBooking);
-            wp_update_post(['ID' => $newBooking]);
+            update_field('outbound_booking_time', $outboundDate, $newBooking);
+            update_field('inbound_booking_time', $inboundDate, $newBooking);
 
             return $newBooking;
         }
@@ -245,7 +270,7 @@ class BookingController
         self::emailUserBookingDetails('paid', $bookingId);
     }
 
-    public function updateOrInsertPostJourney($slug, $seats)
+    public static function updateOrInsertPostJourney($slug, $seats)
     {
         $newJourneyBooking = '';
 
@@ -279,7 +304,7 @@ class BookingController
                 $query->the_post();
                 wp_update_post(get_the_ID());
                 $seatsLeft = get_field('seats', get_the_ID());
-                if ($seatsLeft > $seats) {
+                if ($seatsLeft >= $seats) {
                     update_field('seats', ($seatsLeft - $seats), get_the_ID());
                     $newJourneyBooking = get_the_ID();
                 } else {
