@@ -24,9 +24,31 @@ class JourneyController
                 'methods' => 'GET',
                 'callback' => [$this, 'returnAvailableJourneys'],
             ]);
+
+            // register_rest_route('xplore-booking/v1', '/generate-journey-dates/', [
+            //     'methods' => 'GET',
+            //     'callback' => [$this, 'generateJourneyDates'],
+            // ]);
         });
     }
 
+    public function generateJourneyDates() {
+        $iterator = new \DateTime();
+        $sixMonthsFuture = new \DateTime();
+        $sixMonthsFuture->add(new \DateInterval('P2M'));
+
+        $oneDayInterval = new \DateInterval('P1D');
+        $journeys = self::journeyTimes();
+
+        while($iterator < $sixMonthsFuture) {
+            foreach($journeys as $slug => $journey) {
+                $newSlug = $slug . '-' . $iterator->format('d-m-Y');
+                BookingController::updateOrInsertPostJourney($newSlug, 0);
+            }
+            $iterator->add($oneDayInterval);
+        }
+    }
+
     public static function returnAvailableJourneys($request)
     {
         $departLocation = $request['depart'];
@@ -98,6 +120,8 @@ class JourneyController
 
         $args = [
             'post_type' => 'journey',
+            'orderby' => 'title',
+            'order' => 'ASC',
             'posts_per_page' => -1,
         ];
         $journeys = new \WP_Query($args);
@@ -244,6 +268,12 @@ class JourneyController
 
         /*** TIMES TO DUNDEE ***/
         $inwardJourneys = [
+            'edinburgh-to-dundee-0100' => [
+                'post_title' => 'Edinburgh to Dundee 01:00',
+                'departure_time' => '01:00',
+                'arrival_time' => '02:20',
+                'seats' => self::SEATS,
+            ],
             'edinburgh-to-dundee-0400' => [
                 'post_title' => 'Edinburgh to Dundee 04:00',
                 'departure_time' => '04:00',
@@ -328,12 +358,6 @@ class JourneyController
                 'arrival_time' => '00:50',
                 'seats' => self::SEATS,
             ],
-            'edinburgh-to-dundee-0100' => [
-                'post_title' => 'Edinburgh to Dundee 01:00',
-                'departure_time' => '01:00',
-                'arrival_time' => '02:20',
-                'seats' => self::SEATS,
-            ],
         ];
 
         return array_merge($outwardJourneys, $inwardJourneys);
